﻿using System;

using UIKit;
using Infragistics;
using Foundation;
using System.Collections.Generic;

namespace CheckboxColumn
{
	public partial class ViewController : UIViewController
	{
		IGGridView _gridView;
		IGGridViewDataSourceHelper _dsh;

		protected ViewController(IntPtr handle) : base(handle)
		{
			
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			List<TestData> data = new List<TestData>();
			for (int i = 0; i < 100; i++)
			{
				TestData d = new TestData();
				d.BoolProp = (i % 2) == 0;
				d.Name = "Value: " + i.ToString();
				data.Add(d);
			}

			_gridView = new IGGridView(this.View.Bounds, IGGridViewStyle.IGGridViewStyleDefault);
			_gridView.AutoresizingMask = UIViewAutoresizing.FlexibleDimensions;
			this.View.AddSubview(_gridView);

			_dsh = new IGGridViewDataSourceHelper();
			_dsh.ColumnDefinitions.Add(new CheckboxColumn("boolProp"));
			_dsh.Data = data.ToArray();


			_gridView.DataSource = _dsh;

		}
	}

	public class CheckboxColumn : IGGridViewColumnDefinition
	{
		public CheckboxColumn(String key) : base(key)
		{

		}

		public override IGGridViewCell CreateCell(IGGridView gridView, IGCellPath path, IGGridViewDataSourceHelper dataSource)
		{
			CheckboxCell cell = (CheckboxCell)gridView.DequeueReusableCell("cb");
			if (cell == null)
			{
				cell = new CheckboxCell("cb");
			}

			bool val = ((NSNumber)dataSource.ResolveDataValueForCell(path)).BoolValue;
			cell.UpdateValue(val);

			return cell;
		}
	}

	public class CheckboxCell : IGGridViewCell
	{
		UISwitch _switch;
		public CheckboxCell(String identifier) : base(identifier)
		{
			_switch = new UISwitch();
			this.AddSubview(_switch);
		}

		public override void SetupSize(CoreGraphics.CGSize size)
		{
			base.SetupSize(size);

			_switch.Frame = new CoreGraphics.CGRect(0, 0, size.Width, size.Height);

		}

		public void UpdateValue(bool val)
		{
			_switch.On = val;
		}
	}

	public class TestData : NSObject
	{
		
		[Export("boolProp")]
		public bool BoolProp
		{
			get;
			set;
		}

		[Export("name")]
		public string Name
		{
			get;
			set;
		}
	}
}
